<?php
// $Id: page.tpl.php,v 1.1 2009/10/01 03:34:49 ishmaelsanchez Exp $ 

/**
 *
 * Theme implementation to display a single Drupal page.
 * 
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the theme is located in, e.g. themes/garland
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 * 
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing primary navigation links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing secondary navigation links for
 * - $breadcrumb: The breadcrumb trail for the current page.
 * - $title: The page title, for use in the actual HTML content.
 * - $help: Dynamic help text, mostly for admin pages.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page 
 * - $content: The main content of the current Drupal page.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">

<head>
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $base_path . $directory; ?>/css/ie.css" type="text/css">
  <![endif]-->
  <?php print $scripts; ?>
  </head>

<body class="<?php print $body_classes; ?>">
  <div id="container">
      <div id="header">

        <?php if (!empty($logo)): ?>
          <a href="<?php print $front_page; ?>" title="<?php print check_plain($site_name); ?>" rel="home">
            <img src="<?php print $logo; ?>" alt="<?php print check_plain($site_name); ?>" id="logo" />
          </a>
        <?php endif; ?>

        <?php if (!empty($site_name)): ?>
          <div id="site-name">
            <a href="<?php print $front_page ?>" title="<?php print check_plain($site_name); ?>" rel="home"><?php print $site_name; ?></a>
          </div>
        <?php endif; ?>
  
        <?php if (!empty($site_slogan)): ?>
          <div id="site-slogan">:: <?php print $site_slogan; ?> ::</div>
        <?php endif; ?>
        
        <?php if (!empty($header)): ?>
          <div id="header-block">
            <?php print $header; ?>
          </div>
        <?php endif; ?>

      </div> <!-- /header -->

        <?php if (!empty($primary_links)): ?>
          <div id="nav-primary" class="navigation">
            <?php print theme('links', $primary_links, array('class' => 'links primary-links')); ?>
          </div>
        <?php endif; ?>
      
      <div id="content">
        
        <?php if (!empty($messages)): print $messages; endif; ?>
        <?php if (!empty($help)): print $help; endif; ?>
        <?php if (!empty($tabs)): ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
        
        <?php if (!empty($secondary_links)): ?>
          <div id="secondary" class="navigation">
            <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')); ?>
          </div>
        <?php endif; ?>
        
           <?php if (!empty($content_top)): ?>
            <div id="content-top">
              <?php print $content_top; ?>
            </div> <!-- /content-top -->
          <?php endif; ?>
          
          <div id="content-main">
            <?php if (!empty($title)): ?>
              <h1 class="title" id="page-title"><?php print $title; ?></h1>
            <?php endif; ?>
            <?php print $content; ?>
          </div> <!-- /content-main -->
          
          <?php if(!empty($content_bottom)): ?>  
            <div id="content-bottom">
              <?php print $content_bottom; ?>
            </div> <!-- /content-bottom -->
          <?php endif; ?>
          
          <?php if (!empty($breadcrumb)): ?><div id="breadcrumb"><?php print $breadcrumb; ?></div><?php endif; ?>
      </div> <!-- /content-->

      <?php if ($right || $search_box || $mission): ?>
        <div id="sidebar-right">
          <div class="icons">
            <a class="feed" href="<?php print $base_path?>rss.xml"><img src="<?php print $base_path . $directory; ?>/images/rss.png" title="RSS feed" alt="RSS Feed" /></a>
            <a class="twitter" href="http://twitter.com/<?php print check_plain($site_name); ?>"><img src="<?php print $base_path . $directory; ?>/images/twitter_logo.png" title="Twitter" alt="Twitter" /></a>
            <a class="linkedin" href="http://www.linkedin.com/companies/<?php print check_plain($site_name); ?>"><img src="<?php print $base_path . $directory; ?>/images/linkedin.png" title="Linkedin" alt="Linkedin" /></a>
            <a class="facebook" href="http://www.facebook.com/<?php print check_plain($site_name); ?>"><img src="<?php print $base_path . $directory; ?>/images/facebook.png" title="Facebook" alt="Facebook" /></a>
            <a class="contact" href="<?php print $base_path?>contact"><img src="<?php print $base_path . $directory; ?>/images/contact.png" title="Contact" alt="Contact" /></a>
          </div>
           
          <?php if (!empty($mission)): ?>
           <div id="mission"><?php print $mission; ?></div>
          <?php endif; ?>
          
          <?php if (!empty($search_box)): ?>
            <div id="search-box"><?php print $search_box; ?></div>
          <?php endif; ?>
          
          <div id="sidebar-inner">
            <?php print $right; ?>
          </div>
        </div> <!-- /sidebar-right -->
      <?php endif; ?>

      <div id="footer">
        <div id="footer-inner">
        <?php if (!empty($footer)): print $footer; endif; ?>
        </div>
        
        <?php if (!empty($primary_links)): ?>
          <div id="links" class="navigation">
            <?php print theme('links', $primary_links, array('class' => 'links primary-links')); ?>
          </div>
        <?php endif; ?>
        
        <?php print $footer_message; ?>
        
      </div> <!-- /footer -->

      <?php print $closure; ?>

  </div> <!-- /container -->
</body>
</html>
